MS data (object) — BAGO 0.0.1 documentation

# MS data (object)

This is an object for storing, manipulating and visualizing LC-MS data.

The object contains the following attributes:

> - `rawData`: A `MSExperiment` object (supported by `pyopenms`).

> - `ms1Data`: A `ms1Spectrum` object (supported by `bago`).

> - `ms2Data`: A `ms2Spectrum` object (supported by `bago`).

> - `sNum`: Number of top signals.

> - `topSignals`: Top signals.

> - `intensityBPC`: Intensities of the base peak chromatogram.

> - `rtBPC`: Retention times of the base peak chromatogram.

> - `sepEff`: Separation efficiency.

Parameters are needed to process the MS data. A templete of the parameters can be accessed by

    from bago import bagoMain

    print(bagoMain.parametersTemplate)